@@ -1,7 +1,11 @@
 package Bencher::Scenarios::SPVM;
 
-our $DATE = '2017-08-04'; # DATE
-our $VERSION = '0.002'; # VERSION
+use strict;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-11-23'; # DATE
+our $DIST = 'Bencher-Scenarios-SPVM'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Benchmark SPVM
@@ -18,7 +22,7 @@ Bencher::Scenarios::SPVM - Benchmark SPVM
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenarios::SPVM (from Perl distribution Bencher-Scenarios-SPVM), released on 2017-08-04.
+This document describes version 0.003 of Bencher::Scenarios::SPVM (from Perl distribution Bencher-Scenarios-SPVM), released on 2022-11-23.
 
 =head1 DESCRIPTION
 
@@ -26,7 +30,7 @@ This distribution contains the following L<Bencher> scenario modules:
 
 =over
 
-=item * L<Bencher::Scenario::SPVM::Sum>
+=item * L<Bencher::Scenario::SPVM::Prime>
 
 =back
 
@@ -38,6 +42,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Sc
 
 Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-SPVM>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2017 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-SPVM>
@@ -46,15 +79,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2017 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
